@@ -77,6 +77,8 @@ def youtube_download_by_id(id, title=None, output_dir='.', merge=True, info_only
         stream_list = ytplayer_config['args']['url_encoded_fmt_stream_map'].split(',')
         
         html5player = ytplayer_config['assets']['js']
+        if html5player[0:2] == '//':
+            html5player = 'http:' + html5player
     
     streams = {
         parse.parse_qs(stream)['itag'][0] : parse.parse_qs(stream)
@@ -108,7 +110,7 @@ def youtube_list_download_by_id(list_id, title=None, output_dir='.', merge=True,
     """
 
     video_page = get_content('http://www.youtube.com/playlist?list=%s' % list_id)
-    ids = set(re.findall(r'<a href="\/watch\?v=(\w+)', video_page))
+    ids = set(re.findall(r'<a href="\/watch\?v=([\w-]+)', video_page))
     for id in ids:
         youtube_download_by_id(id, title, output_dir, merge, info_only)
 
